@@ -13,28 +13,29 @@
 ##############################################################################
 """Principal Annotation Tests
 """
+import doctest
 import unittest
-from zope.component import provideAdapter
-from zope.testing import doctest
-from zope.interface import Interface
-from zope.security.interfaces import IPrincipal
-from zope.site.testing import siteSetUp, siteTearDown
 
-from zope.principalannotation.utility import annotations
+from zope.site.testing import siteSetUp, siteTearDown
+from zope.configuration import xmlconfig
+
+import zope.principalannotation
+
 
 def setUp(test):
     site = siteSetUp(site=True)
     test.globs['root'] = site
-    provideAdapter(annotations)
-    provideAdapter(annotations, (IPrincipal, Interface))
+    xmlconfig.file('configure.zcml', zope.principalannotation)
+
 
 def tearDown(test):
     siteTearDown()
 
+
 def test_suite():
     return unittest.TestSuite((
         doctest.DocFileSuite(
-            'README.txt',
+            'README.rst',
             setUp=setUp, tearDown=tearDown,
             optionflags=doctest.ELLIPSIS)
-        ))
+    ))
